@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CheatManager.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: CheatManager.cxx 2926 2014-06-16 16:34:48Z stephena $
 //============================================================================
 
 #include <fstream>
@@ -366,6 +366,6 @@ bool CheatManager::isValidCode(const string& code)
     if(!isxdigit(code[i]))
       return false;
 
-  int length = code.length();
+  uInt32 length = (uInt32)code.length();
   return (length == 4 || length == 6 || length == 8);
 }
