@@ -14,10 +14,9 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: PNGLibrary.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: PNGLibrary.cxx 2929 2014-06-20 00:28:57Z stephena $
 //============================================================================
 
-#include <zlib.h>
 #include <fstream>
 #include <cstring>
 #include <sstream>
@@ -27,11 +26,11 @@
 #include "FrameBuffer.hxx"
 #include "Props.hxx"
 #include "TIA.hxx"
-#include "Version.hxx"
 #include "PNGLibrary.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-PNGLibrary::PNGLibrary()
+PNGLibrary::PNGLibrary(const FrameBuffer& fb)
+  : myFB(fb)
 {
 }
 
@@ -44,10 +43,9 @@ PNGLibrary::~PNGLibrary()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool PNGLibrary::loadImage(const string& filename,
-                           const FrameBuffer& fb, FBSurface& surface)
+void PNGLibrary::loadImage(const string& filename, FBSurface& surface)
 {
-  #define readImageERROR(s) { err_message = s; goto done; }
+  #define loadImageERROR(s) { err_message = s; goto done; }
 
   png_structp png_ptr = NULL;
   png_infop info_ptr = NULL;
@@ -57,18 +55,18 @@ bool PNGLibrary::loadImage(const string& filename,
 
   ifstream in(filename.c_str(), ios_base::binary);
   if(!in.is_open())
-    readImageERROR("No image found");
+    loadImageERROR("No image found");
 
   // Create the PNG loading context structure
   png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL,
                  png_user_error, png_user_warn);
   if(png_ptr == NULL)
-    readImageERROR("Couldn't allocate memory for PNG file");
+    loadImageERROR("Couldn't allocate memory for PNG file");
 
   // Allocate/initialize the memory for image information.  REQUIRED.
 	info_ptr = png_create_info_struct(png_ptr);
   if(info_ptr == NULL)
-    readImageERROR("Couldn't create image information for PNG file");
+    loadImageERROR("Couldn't create image information for PNG file");
 
   // Set up the input control
   png_set_read_fn(png_ptr, &in, png_read_data);
@@ -92,20 +90,20 @@ bool PNGLibrary::loadImage(const string& filename,
   }
   else if(color_type == PNG_COLOR_TYPE_GRAY || color_type == PNG_COLOR_TYPE_GRAY_ALPHA)
   {
-    readImageERROR("Greyscale PNG images not supported");
+    loadImageERROR("Greyscale PNG images not supported");
   }
   else if(color_type == PNG_COLOR_TYPE_PALETTE)
   {
-    readImageERROR("Paletted PNG images not supported");
+    png_set_palette_to_rgb(png_ptr);
   }
   else if(color_type != PNG_COLOR_TYPE_RGB)
   {
-    readImageERROR("Unknown format in PNG image");
+    loadImageERROR("Unknown format in PNG image");
   }
 
   // Create/initialize storage area for the current image
   if(!allocateStorage(iwidth, iheight))
-    readImageERROR("Not enough memory to read PNG file");
+    loadImageERROR("Not enough memory to read PNG file");
 
   // The PNG read function expects an array of rows, not a single 1-D array
   for(uInt32 irow = 0, offset = 0; irow < ReadInfo.height; ++irow, offset += ReadInfo.pitch)
@@ -118,7 +116,7 @@ bool PNGLibrary::loadImage(const string& filename,
   png_read_end(png_ptr, info_ptr);
 
   // Scale image to surface dimensions
-  scaleImagetoSurface(fb, surface);
+  scaleImagetoSurface(surface);
 
   // Cleanup
 done:
@@ -127,142 +125,123 @@ done:
 
   if(err_message)
     throw err_message;
-  else
-    return true;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string PNGLibrary::saveImage(const string& filename,
-                             const FrameBuffer& framebuffer,
-                             const Properties& props)
+void PNGLibrary::saveImage(const string& filename, const VariantList& comments)
 {
   ofstream out(filename.c_str(), ios_base::binary);
   if(!out.is_open())
-    return "ERROR: Couldn't create snapshot file";
+    throw "ERROR: Couldn't create snapshot file";
 
-  // Get actual image dimensions. which are not always the same
-  // as the framebuffer dimensions
-  const GUI::Rect& image = framebuffer.imageRect();
-  uInt32 width = image.width(), height = image.height(),
-         pitch = width * 3;
-  uInt8* buffer = new uInt8[(pitch + 1) * height];
+  const GUI::Rect& rect = myFB.imageRect();
+  png_uint_32 width = rect.width(), height = rect.height();
 
-  // Fill the buffer with scanline data
-  uInt8* buf_ptr = buffer;
-  for(uInt32 row = 0; row < height; row++)
-  {
-    *buf_ptr++ = 0;                      // first byte of row is filter type
-    framebuffer.scanline(row, buf_ptr);  // get another scanline
-    buf_ptr += pitch;                    // add pitch
-  }
+  // Get framebuffer pixel data (we get ABGR format)
+  png_bytep buffer = new png_byte[width * height * 4];
+  myFB.readPixels(buffer, width*4, rect);
 
-  return saveBufferToPNG(out, buffer, width, height,
-                         props, framebuffer.effectsInfo());
+  // Set up pointers into "buffer" byte array
+  png_bytep* rows = new png_bytep[height];
+  for(png_uint_32 k = 0; k < height; ++k)
+    rows[k] = (png_bytep) (buffer + k*width*4);
+
+  // And save the image
+  saveImage(out, buffer, rows, width, height, comments);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string PNGLibrary::saveImage(const string& filename,
-                             const FrameBuffer& framebuffer, const TIA& tia,
-                             const Properties& props)
+void PNGLibrary::saveImage(const string& filename, const FBSurface& surface,
+                           const GUI::Rect& rect, const VariantList& comments)
 {
   ofstream out(filename.c_str(), ios_base::binary);
   if(!out.is_open())
-    return "ERROR: Couldn't create snapshot file";
+    throw "ERROR: Couldn't create snapshot file";
 
-  uInt32 width = tia.width(), height = tia.height();
-  uInt8* buffer = new uInt8[(width*3*2 + 1) * height];
-
-  // Fill the buffer with pixels from the mediasrc
-  uInt8 r, g, b;
-  uInt8* buf_ptr = buffer;
-  for(uInt32 y = 0; y < height; ++y)
+  // Do we want the entire surface or just a section?
+  png_uint_32 width = rect.width(), height = rect.height();
+  if(rect.isEmpty())
   {
-    *buf_ptr++ = 0;   // first byte of row is filter type
-    for(uInt32 x = 0; x < width; ++x)
-    {
-      uInt32 pixel = framebuffer.tiaPixel(y*width+x);
-      framebuffer.getRGB(pixel, &r, &g, &b);
-      *buf_ptr++ = r;
-      *buf_ptr++ = g;
-      *buf_ptr++ = b;
-      *buf_ptr++ = r;
-      *buf_ptr++ = g;
-      *buf_ptr++ = b;
-    }
+    width = surface.width();
+    height = surface.height();
   }
 
-  return saveBufferToPNG(out, buffer, width << 1, height,
-                         props, framebuffer.effectsInfo());
+  // Get the surface pixel data (we get ABGR format)
+  png_bytep buffer = new png_byte[width * height * 4];
+  surface.readPixels(buffer, width, rect);
+
+  // Set up pointers into "buffer" byte array
+  png_bytep* rows = new png_bytep[height];
+  for(png_uint_32 k = 0; k < height; ++k)
+    rows[k] = (png_bytep) (buffer + k*width*4);
+
+  // And save the image
+  saveImage(out, buffer, rows, width, height, comments);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string PNGLibrary::saveBufferToPNG(ofstream& out, uInt8* buffer,
-                                   uInt32 width, uInt32 height,
-                                   const Properties& props,
-                                   const string& effectsInfo)
+void PNGLibrary::saveImage(ofstream& out, png_bytep& buffer, png_bytep*& rows,
+    png_uint_32 width, png_uint_32 height, const VariantList& comments)
 {
-  uInt8* compmem = (uInt8*) NULL;
+  #define saveImageERROR(s) { err_message = s; goto done; }
 
-  try
-  {
-    // PNG file header
-    uInt8 header[8] = { 137, 80, 78, 71, 13, 10, 26, 10 };
-    out.write((const char*)header, 8);
+  png_structp png_ptr = NULL;
+  png_infop info_ptr = NULL;
+  const char* err_message = NULL;
 
-    // PNG IHDR
-    uInt8 ihdr[13];
-    ihdr[0]  = width >> 24;   // width
-    ihdr[1]  = width >> 16;
-    ihdr[2]  = width >> 8;
-    ihdr[3]  = width & 0xFF;
-    ihdr[4]  = height >> 24;  // height
-    ihdr[5]  = height >> 16;
-    ihdr[6]  = height >> 8;
-    ihdr[7]  = height & 0xFF;
-    ihdr[8]  = 8;  // 8 bits per sample (24 bits per pixel)
-    ihdr[9]  = 2;  // PNG_COLOR_TYPE_RGB
-    ihdr[10] = 0;  // PNG_COMPRESSION_TYPE_DEFAULT
-    ihdr[11] = 0;  // PNG_FILTER_TYPE_DEFAULT
-    ihdr[12] = 0;  // PNG_INTERLACE_NONE
-    writePNGChunk(out, "IHDR", ihdr, 13);
+  // Create the PNG saving context structure
+  png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL,
+                 png_user_error, png_user_warn);
+  if(png_ptr == NULL)
+    saveImageERROR("Couldn't allocate memory for PNG file");
 
-    // Compress the data with zlib
-    uLongf compmemsize = (uLongf)((height * (width + 1) * 3 * 1.001 + 1) + 12);
-    compmem = new uInt8[compmemsize];
-    if(compmem == NULL ||
-       (compress(compmem, &compmemsize, buffer, height * (width * 3 + 1)) != Z_OK))
-      throw "ERROR: Couldn't compress PNG";
+  // Allocate/initialize the memory for image information.  REQUIRED.
+	info_ptr = png_create_info_struct(png_ptr);
+  if(info_ptr == NULL)
+    saveImageERROR("Couldn't create image information for PNG file");
 
-    // Write the compressed framebuffer data
-    writePNGChunk(out, "IDAT", compmem, compmemsize);
+  // Set up the output control
+  png_set_write_fn(png_ptr, &out, png_write_data, png_io_flush);
 
-    // Add some info about this snapshot
-    ostringstream text;
-    text << "Stella " << STELLA_VERSION << " (Build " << STELLA_BUILD << ") ["
-         << BSPF_ARCH << "]";
+  // Write PNG header info
+  png_set_IHDR(png_ptr, info_ptr, width, height, 8,
+      PNG_COLOR_TYPE_RGB, PNG_INTERLACE_NONE, PNG_COMPRESSION_TYPE_DEFAULT,
+      PNG_FILTER_TYPE_DEFAULT);
 
-    writePNGText(out, "Software", text.str());
-    writePNGText(out, "ROM Name", props.get(Cartridge_Name));
-    writePNGText(out, "ROM MD5", props.get(Cartridge_MD5));
-    writePNGText(out, "TV Effects", effectsInfo);
+  // Write comments
+  writeComments(png_ptr, info_ptr, comments);
 
-    // Finish up
-    writePNGChunk(out, "IEND", 0, 0);
+  // Write the file header information.  REQUIRED
+  png_write_info(png_ptr, info_ptr);
 
-    // Clean up
-    if(buffer)  delete[] buffer;
-    if(compmem) delete[] compmem;
-    out.close();
+  // Pack pixels into bytes
+  png_set_packing(png_ptr);
 
-    return "Snapshot saved";
-  }
-  catch(const char* msg)
-  {
-    if(buffer)  delete[] buffer;
-    if(compmem) delete[] compmem;
-    out.close();
-    return msg;
-  }
+  // Swap location of alpha bytes from ARGB to RGBA
+  png_set_swap_alpha(png_ptr);
+
+  // Pack ARGB into RGB
+  png_set_filler(png_ptr, 0, PNG_FILLER_AFTER);
+
+  // Flip BGR pixels to RGB
+  png_set_bgr(png_ptr);
+
+  // Write the entire image in one go
+  png_write_image(png_ptr, rows);
+
+  // We're finished writing
+  png_write_end(png_ptr, info_ptr);
+
+  // Cleanup
+done:
+  if(png_ptr)
+    png_destroy_write_struct(&png_ptr, &info_ptr);
+  if(buffer)
+    delete[] buffer;
+  if (rows)
+    delete[] rows;
+  if(err_message)
+    throw err_message;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -308,7 +287,7 @@ bool PNGLibrary::allocateStorage(png_uint_32 w, png_uint_32 h)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void PNGLibrary::scaleImagetoSurface(const FrameBuffer& fb, FBSurface& surface)
+void PNGLibrary::scaleImagetoSurface(FBSurface& surface)
 {
   // Figure out the original zoom level of the snapshot
   // All snapshots generated by Stella are at most some multiple of 320
@@ -319,14 +298,14 @@ void PNGLibrary::scaleImagetoSurface(const FrameBuffer& fb, FBSurface& surface)
   // but since Stella only generates snapshots at up to 10x, we should
   // be fine for a while ...
   uInt32 izoom = uInt32(ceil(ReadInfo.width/320.0)),
-         szoom = surface.getWidth()/320;
+         szoom = surface.width()/320;
 
   uInt32 sw = ReadInfo.width / izoom * szoom,
          sh = ReadInfo.height / izoom * szoom;
-  sw = BSPF_min(sw, surface.getWidth());
-  sh = BSPF_min(sh, surface.getHeight());
-  surface.setWidth(sw);
-  surface.setHeight(sh);
+  sw = BSPF_min(sw, surface.width());
+  sh = BSPF_min(sh, surface.height());
+  surface.setSrcSize(sw, sh);
+  surface.setDstSize(sw, sh);
 
   // Decompress the image, and scale it correctly
   uInt32 buf_offset = ReadInfo.pitch * izoom;
@@ -345,7 +324,7 @@ void PNGLibrary::scaleImagetoSurface(const FrameBuffer& fb, FBSurface& surface)
     uInt32* l_ptr = ReadInfo.line;
     for(uInt32 icol = 0; icol < ReadInfo.width; icol += izoom, i_ptr += i_offset)
     {
-      uInt32 pixel = fb.mapRGB(*i_ptr, *(i_ptr+1), *(i_ptr+2));
+      uInt32 pixel = myFB.mapRGB(*i_ptr, *(i_ptr+1), *(i_ptr+2));
       uInt32 xstride = szoom;
       while(xstride--)
         *l_ptr++ = pixel;
@@ -359,50 +338,23 @@ void PNGLibrary::scaleImagetoSurface(const FrameBuffer& fb, FBSurface& surface)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void PNGLibrary::writePNGChunk(ofstream& out, const char* type,
-                               uInt8* data, int size)
+void PNGLibrary::writeComments(png_structp png_ptr, png_infop info_ptr,
+                               const VariantList& comments)
 {
-  // Stuff the length/type into the buffer
-  uInt8 temp[8];
-  temp[0] = size >> 24;
-  temp[1] = size >> 16;
-  temp[2] = size >> 8;
-  temp[3] = size;
-  temp[4] = type[0];
-  temp[5] = type[1];
-  temp[6] = type[2];
-  temp[7] = type[3];
+  uInt32 numComments = comments.size();
+  if(numComments == 0)
+    return;
 
-  // Write the header
-  out.write((const char*)temp, 8);
-
-  // Append the actual data
-  uInt32 crc = crc32(0, temp + 4, 4);
-  if(size > 0)
+  png_text* text_ptr = new png_text[numComments];
+  for(uInt32 i = 0; i < numComments; ++i)
   {
-    out.write((const char*)data, size);
-    crc = crc32(crc, data, size);
+    text_ptr[i].key = (char*) comments[i].first.c_str();
+    text_ptr[i].text = (char*) comments[i].second.toString().c_str();
+    text_ptr[i].compression = PNG_TEXT_COMPRESSION_NONE;
+    text_ptr[i].text_length = 0;
   }
-
-  // Write the CRC
-  temp[0] = crc >> 24;
-  temp[1] = crc >> 16;
-  temp[2] = crc >> 8;
-  temp[3] = crc;
-  out.write((const char*)temp, 4);
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void PNGLibrary::writePNGText(ofstream& out, const string& key, const string& text)
-{
-  int length = key.length() + 1 + text.length() + 1;
-  uInt8* data = new uInt8[length];
-
-  strcpy((char*)data, key.c_str());
-  strcpy((char*)data + key.length() + 1, text.c_str());
-
-  writePNGChunk(out, "tEXt", data, length-1);
-  delete[] data;
+  png_set_text(png_ptr, info_ptr, text_ptr, numComments);
+  delete[] text_ptr;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
