@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartDebug.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: CartDebug.cxx 2926 2014-06-16 16:34:48Z stephena $
 //============================================================================
 
 #include <time.h>
@@ -31,6 +31,7 @@
 #include "Version.hxx"
 #include "CartDebug.hxx"
 #include "CartDebugWidget.hxx"
+#include "CartRamWidget.hxx"
 using namespace Common;
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -44,11 +45,6 @@ CartDebug::CartDebug(Debugger& dbg, Console& console, const OSystem& osystem)
   // Zero-page RAM is always present
   addRamArea(0x80, 128, 0, 0);
 
-  // Add extended RAM
-  const RamAreaList& areas = console.cartridge().ramAreas();
-  for(RamAreaList::const_iterator i = areas.begin(); i != areas.end(); ++i)
-    addRamArea(i->start, i->size, i->roffset, i->woffset);
-
   // Create bank information for each potential bank, and an extra one for ZP RAM
   // Banksizes greater than 4096 indicate multi-bank ROMs, but we handle only
   // 4K pieces at a time
@@ -396,7 +392,7 @@ string CartDebug::disassemble(uInt16 start, uInt16 lines) const
     else
       buffer << "       ";
 
-    buffer << tag.disasm << setw(length - tag.disasm.length() + 2)
+    buffer << tag.disasm << setw(int(length - tag.disasm.length() + 2))
            << setfill(' ') << " "
            << setw(4) << left << tag.ccount << "   " << tag.bytes << endl;
   }
@@ -772,7 +768,7 @@ string CartDebug::loadListFile()
       if(addr_s.length() == 0)
         continue;
       const char* p = addr_s[0] == 'U' ? addr_s.c_str() + 1 : addr_s.c_str();
-      addr = strtoul(p, NULL, 16);
+      addr = (int)strtoul(p, NULL, 16);
 
       // For now, completely ignore ROM addresses
       if(!(addr & 0x1000))
