@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: DebuggerParser.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: DebuggerParser.cxx 2931 2014-06-20 23:01:11Z stephena $
 //============================================================================
 
 #include <fstream>
@@ -26,6 +26,7 @@
 #include "CpuDebug.hxx"
 #include "RiotDebug.hxx"
 #include "TIADebug.hxx"
+#include "TiaOutputWidget.hxx"
 #include "DebuggerParser.hxx"
 #include "YaccParser.hxx"
 #include "M6502.hxx"
@@ -326,7 +327,7 @@ string DebuggerParser::showWatches()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool DebuggerParser::getArgs(const string& command, string& verb)
 {
-  int state = kIN_COMMAND, i = 0, length = command.length();
+  int state = kIN_COMMAND, i = 0, length = (int)command.length();
   string curArg = "";
   verb = "";
 
@@ -1428,6 +1429,13 @@ void DebuggerParser::executeSaveses()
     commandResult << red("I/O error");
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+// "savesnap"
+void DebuggerParser::executeSavesnap()
+{
+  debugger.tiaOutput().saveSnapshot();
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // "savestate"
 void DebuggerParser::executeSavestate()
@@ -2090,6 +2098,15 @@ DebuggerParser::Command DebuggerParser::commands[kNumCommands] = {
     &DebuggerParser::executeSaveses
   },
 
+  {
+    "savesnap",
+    "Save current TIA image to PNG file",
+    false,
+    false,
+    { kARG_END_ARGS },
+    &DebuggerParser::executeSavesnap
+  },
+
   {
     "savestate",
     "Save emulator state xx (valid args 0-9)",
