@@ -8,16 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2013 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: DataGridWidget.cxx 2743 2013-05-29 16:27:12Z stephena $
-//
-//   Based on code from ScummVM - Scumm Interpreter
-//   Copyright (C) 2002-2004 The ScummVM project
+// $Id: DataGridWidget.cxx 2914 2014-06-10 21:04:36Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -33,7 +30,8 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 DataGridWidget::DataGridWidget(GuiObject* boss, const GUI::Font& font,
                                int x, int y, int cols, int rows,
-                               int colchars, int bits, BaseFormat base,
+                               int colchars, int bits,
+                               Common::Base::Format base,
                                bool useScrollbar)
   : EditableWidget(boss, font, x, y,
                    cols*(colchars * font.getMaxCharWidth() + 8) + 1,
@@ -53,7 +51,6 @@ DataGridWidget::DataGridWidget(GuiObject* boss, const GUI::Font& font,
 {
   _flags = WIDGET_ENABLED | WIDGET_CLEARBG | WIDGET_RETAIN_FOCUS |
            WIDGET_WANTS_RAWDATA;
-  _type = kDataGridWidget;
   _editMode = false;
 
   // The item is selected, thus _bgcolor is used to draw the caret and
@@ -117,10 +114,7 @@ cerr << "alist.size() = "     << alist.size()
   // An efficiency thing
   string temp;
   for(int i = 0; i < size; ++i)
-  {
-    temp = instance().debugger().valueToString(_valueList[i], _base);
-    _valueStringList.push_back(temp);
-  }
+    _valueStringList.push_back(Common::Base::toString(_valueList[i], _base));
 
 /*
 cerr << "_addrList.size() = "     << _addrList.size()
@@ -199,7 +193,7 @@ void DataGridWidget::setValue(int position, int value, bool changed)
   if(position >= 0 && uInt32(position) < _valueList.size())
   {
     // Correctly format the data for viewing
-    _editString = instance().debugger().valueToString(value, _base);
+    _editString = Common::Base::toString(value, _base);
 
     _valueStringList[position] = _editString;
     _changedList[position] = changed;
@@ -286,7 +280,18 @@ int DataGridWidget::findItem(int x, int y)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
+bool DataGridWidget::handleText(char text)
+{
+  if(_editMode)
+  {
+    // Class EditableWidget handles all text editing related key presses for us
+    return EditableWidget::handleText(text);
+  }
+  return false;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod)
 {
   // Ignore all mod keys
   if(instance().eventHandler().kbdControl(mod) ||
@@ -298,17 +303,15 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
 
   if (_editMode)
   {
-    // Class EditableWidget handles all text editing related key presses for us
-    handled = EditableWidget::handleKeyDown(key, mod, ascii);
-    if(handled)
-      setDirty(); draw();
+    // Class EditableWidget handles all single-key presses for us
+    handled = EditableWidget::handleKeyDown(key, mod);
   }
   else
   {
-    // not editmode
     switch(key)
     {
       case KBDK_RETURN:
+      case KBDK_KP_ENTER:
         if (_currentRow >= 0 && _currentCol >= 0)
         {
           dirty = true;
@@ -409,58 +412,44 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
         }
         break;
 
-      case KBDK_n: // negate
+      case KBDK_N: // negate
         if(_editable)
           negateCell();
         break;
 
+      case KBDK_I: // invert
+        if(_editable)
+          invertCell();
+        break;
+
+      case KBDK_MINUS: // decrement
+        if(_editable)
+          decrementCell();
+        break;
+
+      case KBDK_EQUALS: // increment
+        if(_editable)
+          incrementCell();
+        break;
+
+      case KBDK_COMMA: // shift left
+        if(_editable)
+          lshiftCell();
+        break;
+
+      case KBDK_PERIOD: // shift right
+        if(_editable)
+          rshiftCell();
+        break;
+
+      case KBDK_Z: // zero
+        if(_editable)
+          zeroCell();
+        break;
+
       default:
         handled = false;
     }
-    if(!handled)
-    {
-      handled = true;
-
-      switch(ascii)
-      {
-        case 'i': // invert
-        case '!':
-          if(_editable)
-            invertCell();
-          break;
-
-        case '-': // decrement
-          if(_editable)
-            decrementCell();
-          break;
-
-        case '+': // increment
-        case '=':
-          if(_editable)
-            incrementCell();
-          break;
-
-        case '<': // shift left
-        case ',':
-          if(_editable)
-            lshiftCell();
-          break;
-
-        case '>': // shift right
-        case '.':
-          if(_editable)
-            rshiftCell();
-          break;
-
-        case 'z': // zero
-          if(_editable)
-            zeroCell();
-          break;
-
-        default:
-          handled = false;
-      }
-    }
   }
 
   if (dirty)
@@ -479,7 +468,7 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool DataGridWidget::handleKeyUp(StellaKey key, StellaMod mod, char ascii)
+bool DataGridWidget::handleKeyUp(StellaKey key, StellaMod mod)
 {
   if (key == _currentKeyDown)
     _currentKeyDown = KBDK_UNKNOWN;
@@ -511,7 +500,7 @@ void DataGridWidget::lostFocusWidget()
 void DataGridWidget::handleCommand(CommandSender* sender, int cmd,
                                    int data, int id)
 {
-  switch (cmd)
+  switch(cmd)
   {
     case kSetPositionCmd:
       // Chain access; pass to parent
@@ -652,10 +641,33 @@ void DataGridWidget::endEditMode()
   if (!_editMode)
     return;
 
-  // send a message that editing finished with a return/enter key press
   _editMode = false;
 
   // Update the both the string representation and the real data
+  if(_editString.size() > 0 && !(_editString[0] == '$' ||
+        _editString[0] == '#' || _editString[0] == '\\'))
+  {
+    switch(_base)
+    {
+      case Common::Base::F_16:
+      case Common::Base::F_16_1:
+      case Common::Base::F_16_2:
+      case Common::Base::F_16_4:
+      case Common::Base::F_16_8:
+        _editString.insert(0, 1, '$');
+        break;
+      case Common::Base::F_2:
+      case Common::Base::F_2_8:
+      case Common::Base::F_2_16:
+        _editString.insert(0, 1, '\\');
+        break;
+      case Common::Base::F_10:
+        _editString.insert(0, 1, '#');
+        break;
+      case Common::Base::F_DEFAULT:
+        break;
+    }
+  }
   int value = instance().debugger().stringToValue(_editString);
   if(value < _lowerBound || value >= _upperBound)
   {
@@ -677,16 +689,34 @@ void DataGridWidget::abortEditMode()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool DataGridWidget::tryInsertChar(char c, int pos)
 {
-  // Not sure how efficient this is, or should we even care?
+  // Input is very strict here, to eliminate time-consuming error checking
+  // elsewhere, and includes the following restrictions:
+  //    Cannot contain spaces
+  //    Starts with leading specifier ($, #, \), or with a base character
+  //    Only one specifier is allowed
+  //    If starting with a specifier, only allow numbers applicable to that
+  //    base to follow
+
   c = tolower(c);
-  if((c >= '0' && c <= '9') || (c >= 'a' && c <= 'f') ||
-     c == '\\' || c == '#' || c == '$')
-  {
+  bool isBin = c == '0' || c == '1',
+       isDec = c >= '0' && c <= '9',
+       isHex = isDec || (c >= 'a' && c <= 'f'),
+       isOp = c == '$' || c == '#' || c == '\\',
+       insert = false;
+
+  if(BSPF_startsWithIgnoreCase(_editString, "$"))
+    insert = isHex && pos > 0;
+  else if(BSPF_startsWithIgnoreCase(_editString, "#"))
+    insert = isDec && pos > 0;
+  else if(BSPF_startsWithIgnoreCase(_editString, "\\"))
+    insert = isBin && pos > 0;
+  else 
+    insert = isHex || isDec || isBin || isOp;
+
+  if(insert)
     _editString.insert(pos, 1, c);
-    return true;
-  }
-  else
-    return false;
+
+  return insert;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
