@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: RomListWidget.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: RomListWidget.cxx 2914 2014-06-10 21:04:36Z stephena $
 //============================================================================
 
 #include "bspf.hxx"
@@ -272,7 +272,18 @@ void RomListWidget::handleMouseWheel(int x, int y, int direction)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool RomListWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
+bool RomListWidget::handleText(char text)
+{
+  if(_editMode)
+  {
+    // Class EditableWidget handles all text editing related key presses for us
+    return EditableWidget::handleText(text);
+  }
+  return false;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool RomListWidget::handleKeyDown(StellaKey key, StellaMod mod)
 {
   // Ignore all Alt-mod keys
   if(instance().eventHandler().kbdAlt(mod))
@@ -283,12 +294,11 @@ bool RomListWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
 
   if (_editMode)
   {
-    // Class EditableWidget handles all text editing related key presses for us
-    handled = EditableWidget::handleKeyDown(key, mod, ascii);
+    // Class EditableWidget handles all single-key presses for us
+    handled = EditableWidget::handleKeyDown(key, mod);
   }
   else
   {
-    // not editmode
     switch (key)
     {
       case KBDK_SPACE:
@@ -316,7 +326,7 @@ bool RomListWidget::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool RomListWidget::handleKeyUp(StellaKey key, StellaMod mod, char ascii)
+bool RomListWidget::handleKeyUp(StellaKey key, StellaMod mod)
 {
   if (key == _currentKeyDown)
     _currentKeyDown = KBDK_UNKNOWN;
