@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Cart.cxx 2839 2014-01-19 19:41:27Z stephena $
+// $Id: Cart.cxx 2921 2014-06-13 16:28:28Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -34,6 +34,7 @@
 #include "CartCM.hxx"
 #include "CartCTY.hxx"
 #include "CartCV.hxx"
+#include "CartDASH.hxx"
 #include "CartDPC.hxx"
 #include "CartDPCPlus.hxx"
 #include "CartE0.hxx"
@@ -199,6 +200,8 @@ Cartridge* Cartridge::create(const uInt8* image, uInt32 size, string& md5,
     cartridge = new CartridgeCTY(image, size, osystem);
   else if(type == "CV")
     cartridge = new CartridgeCV(image, size, settings);
+  else if(type == "DASH")
+    cartridge = new CartridgeDASH(image, size, settings);
   else if(type == "DPC")
     cartridge = new CartridgeDPC(image, size, settings);
   else if(type == "DPC+")
@@ -340,20 +343,6 @@ bool Cartridge::bankChanged()
   return changed;
 }
 
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Cartridge::registerRamArea(uInt16 start, uInt16 size,
-                                uInt16 roffset, uInt16 woffset)
-{
-#ifdef DEBUGGER_SUPPORT
-  RamArea area;
-  area.start   = start;
-  area.size    = size;
-  area.roffset = roffset;
-  area.woffset = woffset;
-  myRamAreaList.push_back(area);
-#endif
-}
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Cartridge::triggerReadFromWritePort(uInt16 address)
 {
@@ -579,6 +568,7 @@ bool Cartridge::isProbablySC(const uInt8* image, uInt32 size)
   return true;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Cartridge::isProbably4KSC(const uInt8* image, uInt32 size)
 {
   // We check if the first 256 bytes are identical *and* if there's
@@ -595,7 +585,6 @@ bool Cartridge::isProbably4KSC(const uInt8* image, uInt32 size)
   return false;
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Cartridge::isProbablyARM(const uInt8* image, uInt32 size)
 {
@@ -696,6 +685,12 @@ bool Cartridge::isProbablyCV(const uInt8* image, uInt32 size)
     return searchForBytes(image, size, signature[1], 3, 1);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool Cartridge::isProbablyDASH(const uInt8* image, uInt32 size)
+{
+  return false;  // TODO - add autodetection
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool Cartridge::isProbablyDPCplus(const uInt8* image, uInt32 size)
 {
