@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Cart3E.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: Cart3E.cxx 2921 2014-06-13 16:28:28Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -37,11 +37,6 @@ Cartridge3E::Cartridge3E(const uInt8* image, uInt32 size,
   memcpy(myImage, image, mySize);
   createCodeAccessBase(mySize + 32768);
 
-  // This cart can address a 1024 byte bank of RAM @ 0x1000
-  // However, it may not be addressable all the time (it may be swapped out)
-  // so probably most of the time, the area will point to ROM instead
-  registerRamArea(0x1000, 1024, 0x00, 0x400);  // 1024 bytes RAM @ 0x1000
-
   // Remember startup bank
   myStartBank = 0;
 }
