@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2013 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartCTY.cxx 2613 2013-02-17 00:19:14Z stephena $
+// $Id: CartCTY.cxx 2921 2014-06-13 16:28:28Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -42,9 +42,6 @@ CartridgeCTY::CartridgeCTY(const uInt8* image, uInt32 size, const OSystem& osyst
   memcpy(myImage, image, BSPF_min(32768u, size));
   createCodeAccessBase(32768);
 
-  // This cart contains 64 bytes extended RAM @ 0x1000
-  registerRamArea(0x1000, 64, 0x40, 0x00);
-
   // Point to the first tune
   myFrequencyImage = CartCTYTunes;
 
