@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartE7.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: CartE7.cxx 2921 2014-06-13 16:28:28Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -31,13 +31,6 @@ CartridgeE7::CartridgeE7(const uInt8* image, uInt32 size, const Settings& settin
   memcpy(myImage, image, BSPF_min(16384u, size));
   createCodeAccessBase(16384 + 2048);
 
-  // This cart can address a 1024 byte bank of RAM @ 0x1000
-  // and 256 bytes @ 0x1800
-  // However, it may not be addressable all the time (it may be swapped out)
-  // so probably most of the time, the area will point to ROM instead
-  registerRamArea(0x1000, 1024, 0x400, 0x00);  // 1024 bytes RAM @ 0x1000
-  registerRamArea(0x1800, 256, 0x100, 0x00);   // 256 bytes RAM @ 0x1800
-
   // Remember startup bank
   myStartBank = 0;
 }
