@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartF8SC.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: CartF8SC.cxx 2921 2014-06-13 16:28:28Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -31,9 +31,6 @@ CartridgeF8SC::CartridgeF8SC(const uInt8* image, uInt32 size, const Settings& se
   memcpy(myImage, image, BSPF_min(8192u, size));
   createCodeAccessBase(8192);
 
-  // This cart contains 128 bytes extended RAM @ 0x1000
-  registerRamArea(0x1000, 128, 0x80, 0x00);
-
   // Remember startup bank
   myStartBank = 1;
 }
