@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2013 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: CartFA.cxx 2579 2013-01-04 19:49:01Z stephena $
+// $Id: CartFA.cxx 2921 2014-06-13 16:28:28Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -31,9 +31,6 @@ CartridgeFA::CartridgeFA(const uInt8* image, uInt32 size, const Settings& settin
   memcpy(myImage, image, BSPF_min(12288u, size));
   createCodeAccessBase(12288);
 
-  // This cart contains 256 bytes extended RAM @ 0x1000
-  registerRamArea(0x1000, 256, 0x100, 0x00);
-
   // Remember startup bank
   myStartBank = 2;
 }
