@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Settings.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: Settings.cxx 2908 2014-06-04 16:01:45Z stephena $
 //============================================================================
 
 #include <cassert>
@@ -24,57 +24,51 @@
 
 #include "bspf.hxx"
 
-#include "DebuggerDialog.hxx"
 #include "OSystem.hxx"
 #include "Version.hxx"
 
+#ifdef DEBUGGER_SUPPORT
+  #include "DebuggerDialog.hxx"
+#endif
+
 #include "Settings.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Settings::Settings(OSystem* osystem)
+Settings::Settings(OSystem& osystem)
   : myOSystem(osystem)
 {
-  // Add this settings object to the OSystem
-  myOSystem->attach(this);
-
-  // Add options that are common to all versions of Stella
-  setInternal("video", "soft");
-
-  // OpenGL specific options
-  setInternal("gl_inter", "false");
-  setInternal("gl_aspectn", "90");
-  setInternal("gl_aspectp", "100");
-  setInternal("gl_fsscale", "false");
-  setInternal("gl_lib", "libGL.so");
-  setInternal("gl_vsync", "true");
-  setInternal("gl_vbo", "true");
-
-  // Framebuffer-related options
-  setInternal("tia_filter", "zoom2x");
-  setInternal("fullscreen", "0");
-  setInternal("fullres", "auto");
+  // Video-related options
+  setInternal("video", "");
+  setInternal("vsync", "true");
+  setInternal("fullscreen", "false");
   setInternal("center", "false");
-  setInternal("grabmouse", "true");
   setInternal("palette", "standard");
   setInternal("colorloss", "true");
   setInternal("timing", "sleep");
   setInternal("uimessages", "true");
 
+  // TIA specific options
+  setInternal("tia.zoom", "2");
+  setInternal("tia.inter", "false");
+  setInternal("tia.aspectn", "90");
+  setInternal("tia.aspectp", "100");
+  setInternal("tia.fsfill", "false");
+
   // TV filtering options
-  setInternal("tv_filter", "0");
-  setInternal("tv_scanlines", "25");
-  setInternal("tv_scaninter", "true");
+  setInternal("tv.filter", "0");
+  setInternal("tv.scanlines", "25");
+  setInternal("tv.scaninter", "true");
   // TV options when using 'custom' mode
-  setInternal("tv_contrast", "0.0");
-  setInternal("tv_brightness", "0.0");
-  setInternal("tv_hue", "0.0");
-  setInternal("tv_saturation", "0.0");
-  setInternal("tv_gamma", "0.0");
-  setInternal("tv_sharpness", "0.0");
-  setInternal("tv_resolution", "0.0");
-  setInternal("tv_artifacts", "0.0");
-  setInternal("tv_fringing", "0.0");
-  setInternal("tv_bleed", "0.0");
+  setInternal("tv.contrast", "0.0");
+  setInternal("tv.brightness", "0.0");
+  setInternal("tv.hue", "0.0");
+  setInternal("tv.saturation", "0.0");
+  setInternal("tv.gamma", "0.0");
+  setInternal("tv.sharpness", "0.0");
+  setInternal("tv.resolution", "0.0");
+  setInternal("tv.artifacts", "0.0");
+  setInternal("tv.fringing", "0.0");
+  setInternal("tv.bleed", "0.0");
 
   // Sound options
   setInternal("sound", "true");
@@ -89,6 +83,8 @@ Settings::Settings(OSystem* osystem)
   setInternal("joydeadzone", "13");
   setInternal("joyallow4", "false");
   setInternal("usemouse", "analog");
+  setInternal("grabmouse", "true");
+  setInternal("hidecursor", "false");
   setInternal("dsense", "5");
   setInternal("msense", "7");
   setInternal("saport", "lr");
@@ -120,9 +116,11 @@ Settings::Settings(OSystem* osystem)
   setInternal("lastrom", "");
 
   // UI-related options
+#ifdef DEBUGGER_SUPPORT
   setInternal("dbg.res",
-    GUI::Size(DebuggerDialog::kMediumFontMinW, DebuggerDialog::kMediumFontMinH));
-  setInternal("uipalette", "0");
+    GUI::Size(DebuggerDialog::kMediumFontMinW,
+              DebuggerDialog::kMediumFontMinH));
+#endif
   setInternal("listdelay", "300");
   setInternal("mwheel", "4");
 
@@ -139,6 +137,7 @@ Settings::Settings(OSystem* osystem)
   setExternal("romloadcount", "0");
   setExternal("maxres", "");
 
+#ifdef DEBUGGER_SUPPORT
   // Debugger/disassembly options
   setInternal("dbg.fontstyle", "0");
   setInternal("dbg.uhex", "true");
@@ -146,9 +145,12 @@ Settings::Settings(OSystem* osystem)
   setInternal("dis.gfxformat", "2");
   setInternal("dis.showaddr", "true");
   setInternal("dis.relocate", "false");
+#endif
 
+#ifdef DTHUMB_SUPPORT
   // Thumb ARM emulation options
   setInternal("thumb.trapfatal", "true");
+#endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -164,10 +166,10 @@ void Settings::loadConfig()
   string line, key, value;
   string::size_type equalPos, garbage;
 
-  ifstream in(myOSystem->configFile().c_str());
+  ifstream in(myOSystem.configFile().c_str());
   if(!in || !in.is_open())
   {
-    myOSystem->logMessage("ERROR: Couldn't load settings file", 0);
+    myOSystem.logMessage("ERROR: Couldn't load settings file", 0);
     return;
   }
 
@@ -235,7 +237,7 @@ string Settings::loadCommandLine(int argc, char** argv)
       if(++i >= argc)
       {
         buf << "Missing argument for '" << key << "'" << endl;
-        myOSystem->logMessage(buf.str(), 0);
+        myOSystem.logMessage(buf.str(), 0);
         return "";
       }
       string value = argv[i];
@@ -256,7 +258,7 @@ string Settings::loadCommandLine(int argc, char** argv)
         buf << "(E)\n";
       }
 
-      myOSystem->logMessage(buf.str(), 2);
+      myOSystem.logMessage(buf.str(), 2);
     }
     else
       return key;
@@ -271,22 +273,16 @@ void Settings::validate()
   string s;
   int i;
 
-  s = getString("video");
-  if(s != "soft" && s != "gl")  setInternal("video", "soft");
-
   s = getString("timing");
   if(s != "sleep" && s != "busy")  setInternal("timing", "sleep");
 
-#ifdef DISPLAY_OPENGL
-  i = getInt("gl_aspectn");
-  if(i < 80 || i > 120)  setInternal("gl_aspectn", "100");
-  i = getInt("gl_aspectp");
-  if(i < 80 || i > 120)  setInternal("gl_aspectp", "100");
+  i = getInt("tia.aspectn");
+  if(i < 80 || i > 120)  setInternal("tia.aspectn", "90");
+  i = getInt("tia.aspectp");
+  if(i < 80 || i > 120)  setInternal("tia.aspectp", "100");
 
-  i = getInt("tv_filter");
-  if(i < 0 || i > 5)  setInternal("tv_filter", "0");
-
-#endif
+  i = getInt("tv.filter");
+  if(i < 0 || i > 5)  setInternal("tv.filter", "0");
 
 #ifdef SOUND_SUPPORT
   i = getInt("volume");
@@ -345,38 +341,17 @@ void Settings::usage()
     << "Valid options are:" << endl
     << endl
     << "  -video        <type>         Type is one of the following:\n"
-    << "                 soft            SDL software mode\n"
-  #ifdef DISPLAY_OPENGL
-    << "                 gl              SDL OpenGL mode\n"
-    << endl
-    << "  -gl_lib       <name>         Specify the OpenGL library\n"
-    << "  -gl_inter     <1|0>          Enable interpolated (smooth) scaling\n"
-    << "  -gl_aspectn   <number>       Scale the TIA width by the given percentage in NTSC mode\n"
-    << "  -gl_aspectp   <number>       Scale the TIA width by the given percentage in PAL mode\n"
-    << "  -gl_fsscale   <1|0>          Stretch GL image in fullscreen emulation mode to max/integer scale\n"
-    << "  -gl_vsync     <1|0>          Enable 'synchronize to vertical blank interrupt'\n"
-    << "  -gl_vbo       <1|0>          Enable 'vertex buffer objects'\n"
-    << endl
-    << "  -tv_filter    <0-5>          Set TV effects off (0) or to specified mode (1-5)\n"
-    << "  -tv_scanlines <0-100>        Set scanline intensity to percentage (0 disables completely)\n"
-    << "  -tv_scaninter <1|0>          Enable interpolated (smooth) scanlines\n"
-    << "  -tv_contrast    <value>      Set TV effects custom contrast to value 1.0 - 1.0\n"
-    << "  -tv_brightness  <value>      Set TV effects custom brightness to value 1.0 - 1.0\n"
-    << "  -tv_hue         <value>      Set TV effects custom hue to value 1.0 - 1.0\n"
-    << "  -tv_saturation  <value>      Set TV effects custom saturation to value 1.0 - 1.0\n"
-    << "  -tv_gamma       <value>      Set TV effects custom gamma to value 1.0 - 1.0\n"
-    << "  -tv_sharpness   <value>      Set TV effects custom sharpness to value 1.0 - 1.0\n"
-    << "  -tv_resolution  <value>      Set TV effects custom resolution to value 1.0 - 1.0\n"
-    << "  -tv_artifacts   <value>      Set TV effects custom artifacts to value 1.0 - 1.0\n"
-    << "  -tv_fringing    <value>      Set TV effects custom fringing to value 1.0 - 1.0\n"
-    << "  -tv_bleed       <value>      Set TV effects custom bleed to value 1.0 - 1.0\n"
-    << endl
+  #ifdef BSPF_WINDOWS
+    << "                 direct3d        Direct3D acceleration\n"
   #endif
-    << "  -tia_filter   <filter>       Use the specified filter in emulation mode\n"
-    << "  -fullscreen   <1|0|-1>       Use fullscreen mode (1 or 0), or disable switching to fullscreen entirely\n"
-    << "  -fullres      <auto|WxH>     The resolution to use in fullscreen mode\n"
+    << "                 opengl          OpenGL acceleration\n"
+    << "                 opengles2       OpenGLES 2 acceleration\n"
+    << "                 opengles        OpenGLES 1 acceleration\n"
+    << "                 software        Software mode (no acceleration)\n"
+    << endl
+    << "  -vsync        <1|0>          Enable 'synchronize to vertical blank interrupt'\n"
+    << "  -fullscreen   <1|0>          Enable fullscreen mode\n"
     << "  -center       <1|0>          Centers game window (if possible)\n"
-    << "  -grabmouse    <1|0>          Keeps the mouse in the game window\n"
     << "  -palette      <standard|     Use the specified color palette\n"
     << "                 z26|\n"
     << "                 user>\n"
@@ -392,6 +367,26 @@ void Settings::usage()
     << "  -volume       <number>       Set the volume (0 - 100)\n"
     << endl
   #endif
+    << "  -tia.zoom     <zoom>         Use the specified zoom level (windowed mode) for TIA image\n"
+    << "  -tia.inter    <1|0>          Enable interpolated (smooth) scaling for TIA image\n"
+    << "  -tia.aspectn  <number>       Scale TIA width by the given percentage in NTSC mode\n"
+    << "  -tia.aspectp  <number>       Scale TIA width by the given percentage in PAL mode\n"
+    << "  -tia.fsfill   <1|0>          Stretch TIA image to fill fullscreen mode\n"
+    << endl
+    << "  -tv.filter    <0-5>          Set TV effects off (0) or to specified mode (1-5)\n"
+    << "  -tv.scanlines <0-100>        Set scanline intensity to percentage (0 disables completely)\n"
+    << "  -tv.scaninter <1|0>          Enable interpolated (smooth) scanlines\n"
+    << "  -tv.contrast    <value>      Set TV effects custom contrast to value 1.0 - 1.0\n"
+    << "  -tv.brightness  <value>      Set TV effects custom brightness to value 1.0 - 1.0\n"
+    << "  -tv.hue         <value>      Set TV effects custom hue to value 1.0 - 1.0\n"
+    << "  -tv.saturation  <value>      Set TV effects custom saturation to value 1.0 - 1.0\n"
+    << "  -tv.gamma       <value>      Set TV effects custom gamma to value 1.0 - 1.0\n"
+    << "  -tv.sharpness   <value>      Set TV effects custom sharpness to value 1.0 - 1.0\n"
+    << "  -tv.resolution  <value>      Set TV effects custom resolution to value 1.0 - 1.0\n"
+    << "  -tv.artifacts   <value>      Set TV effects custom artifacts to value 1.0 - 1.0\n"
+    << "  -tv.fringing    <value>      Set TV effects custom fringing to value 1.0 - 1.0\n"
+    << "  -tv.bleed       <value>      Set TV effects custom bleed to value 1.0 - 1.0\n"
+    << endl
     << "  -cheat        <code>         Use the specified cheatcode (see manual for description)\n"
     << "  -loglevel     <0|1|2>        Set level of logging during application run\n"
     << "  -logtoconsole <1|0>          Log output to console/commandline\n"
@@ -400,6 +395,8 @@ void Settings::usage()
     << "  -usemouse     <always|\n"
     << "                 analog|\n"
     << "                 never>        Use mouse as a controller as specified by ROM properties in given mode(see manual)\n"
+    << "  -grabmouse    <1|0>          Locks the mouse cursor in the TIA window\n"
+    << "  -hidecursor   <1|0>          Always hide the cursor, or show it when appropriate\n"
     << "  -dsense       <number>       Sensitivity of digital emulated paddle movement (1-10)\n"
     << "  -msense       <number>       Sensitivity of mouse emulated paddle movement (1-15)\n"
     << "  -saport       <lr|rl>        How to assign virtual ports to multiple Stelladaptor/2600-daptors\n"
@@ -424,9 +421,9 @@ void Settings::usage()
     << "                 allroms|        (exts is a ':' separated list of extensions)\n"
     << "                 exts\n"
     << "  -romviewer    <0|1|2>        Show ROM info viewer at given zoom level in ROM launcher (0 for off)\n"
-    << "  -uipalette    <1|2>          Used the specified palette for UI elements\n"
     << "  -listdelay    <delay>        Time to wait between keypresses in list widgets (300-1000)\n"
     << "  -mwheel       <lines>        Number of lines the mouse wheel will scroll in UI\n"
+    << "  -romdir       <dir>          Directory in which to load ROM files\n"
     << "  -statedir     <dir>          Directory in which to save/load state files\n"
     << "  -cheatfile    <file>         Full pathname of cheatfile database\n"
     << "  -palettefile  <file>         Full pathname of user-defined palette file\n"
@@ -434,7 +431,6 @@ void Settings::usage()
     << "  -nvramdir     <dir>          Directory in which to save/load flash/EEPROM files\n"
     << "  -cfgdir       <dir>          Directory in which to save Distella config files\n"
     << "  -avoxport     <name>         The name of the serial port where an AtariVox is connected\n"
-    << "  -maxres       <WxH>          Used by developers to force the maximum size of the application window\n"
     << "  -holdreset                   Start the emulator with the Game Reset switch held down\n"
     << "  -holdselect                  Start the emulator with the Game Select switch held down\n"
     << "  -holdjoy0     <U,D,L,R,F>    Start the emulator with the left joystick direction/fire button held down\n"
@@ -442,6 +438,7 @@ void Settings::usage()
     << "  -tiadriven    <1|0>          Drive unused TIA pins randomly on a read/peek\n"
     << "  -cpurandom    <1|0>          Randomize the contents of CPU registers on reset\n"
     << "  -ramrandom    <1|0>          Randomize the contents of RAM on reset\n"
+    << "  -maxres       <WxH>          Used by developers to force the maximum size of the application window\n"
     << "  -help                        Show the text you're now reading\n"
   #ifdef DEBUGGER_SUPPORT
     << endl
@@ -518,10 +515,10 @@ void Settings::saveConfig()
   if(!settingsChanged)
     return;
 
-  ofstream out(myOSystem->configFile().c_str());
+  ofstream out(myOSystem.configFile().c_str());
   if(!out || !out.is_open())
   {
-    myOSystem->logMessage("ERROR: Couldn't save settings file", 0);
+    myOSystem.logMessage("ERROR: Couldn't save settings file", 0);
     return;
   }
 
@@ -679,7 +676,8 @@ int Settings::setExternal(const string& key, const Variant& value,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Settings::Settings(const Settings&)
+Settings::Settings(const Settings& s)
+  : myOSystem(s.myOSystem)
 {
 }
 
