@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: ContextMenu.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: ContextMenu.cxx 2923 2014-06-13 19:53:44Z stephena $
 //============================================================================
 
 #include "OSystem.hxx"
@@ -102,7 +102,7 @@ void ContextMenu::center()
   if(x + _w > tx) x -= (x + _w - tx);
   if(y + _h > ty) y -= (y + _h - ty);
 
-  surface().setPos(x, y);
+  surface().setDstPos(x, y);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -110,8 +110,8 @@ void ContextMenu::recalc(const GUI::Rect& image)
 {
   // Now is the time to adjust the height
   // If it's higher than the screen, we need to scroll through
-  int maxentries = BSPF_min(18, (image.height() - 4) / _rowHeight);
-  if((int)_entries.size() > maxentries)
+  uInt32 maxentries = BSPF_min(18u, (image.height() - 4) / _rowHeight);
+  if(_entries.size() > maxentries)
   {
     // We show two less than the max, so we have room for two scroll buttons
     _numEntries = maxentries - 2;
@@ -288,7 +288,7 @@ void ContextMenu::handleMouseWheel(int x, int y, int direction)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void ContextMenu::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
+void ContextMenu::handleKeyDown(StellaKey key, StellaMod mod)
 {
   handleEvent(instance().eventHandler().eventForKey(key, kMenuMode));
 }
@@ -595,5 +595,5 @@ void ContextMenu::drawDialog()
   }
 
   // Commit surface changes to screen
-  s.update();
+  s.render();
 }
