@@ -8,13 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2013 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Dialog.cxx 2747 2013-06-17 15:57:41Z stephena $
+// $Id: Dialog.cxx 2913 2014-06-10 16:43:35Z stephena $
 //
 //   Based on code from ScummVM - Scumm Interpreter
 //   Copyright (C) 2002-2004 The ScummVM project
@@ -37,7 +37,7 @@
  */
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Dialog::Dialog(OSystem* instance, DialogContainer* parent,
-               int x, int y, int w, int h, bool isBase)
+               int x, int y, int w, int h)
   : GuiObject(*instance, *parent, *this, x, y, w, h),
     _mouseWidget(0),
     _focusedWidget(0),
@@ -45,7 +45,6 @@ Dialog::Dialog(OSystem* instance, DialogContainer* parent,
     _okWidget(0),
     _cancelWidget(0),
     _visible(false),
-    _isBase(isBase),
     _processCancel(false),
     _surface(0),
     _tabID(0)
@@ -78,7 +77,7 @@ void Dialog::open(bool refresh)
   // ignore it
   if(_surface == NULL)
   {
-    uInt32 surfaceID = instance().frameBuffer().allocateSurface(_w, _h, _isBase);
+    uInt32 surfaceID = instance().frameBuffer().allocateSurface(_w, _h);
     _surface = instance().frameBuffer().surface(surfaceID);
   }
   parent().addDialog(this);
@@ -120,10 +119,10 @@ void Dialog::center()
 {
   if(_surface)
   {
-    const GUI::Rect& screen = instance().frameBuffer().screenRect();
-    uInt32 x = (screen.width() - getWidth()) >> 1;
-    uInt32 y = (screen.height() - getHeight()) >> 1;
-    _surface->setPos(x, y);
+    const GUI::Size& screen = instance().frameBuffer().screenSize();
+    uInt32 x = (screen.w - getWidth()) >> 1;
+    uInt32 y = (screen.h - getHeight()) >> 1;
+    _surface->setDstPos(x, y);
   }
 }
 
@@ -316,11 +315,19 @@ void Dialog::drawDialog()
   }
 
   // Commit surface changes to screen
-  s.update();
+  s.render();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
+void Dialog::handleText(char text)
+{
+  // Focused widget receives text events
+  if(_focusedWidget)
+    _focusedWidget->handleText(text);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Dialog::handleKeyDown(StellaKey key, StellaMod mod)
 {
   // Test for TAB character
   // Shift-left/shift-right cursor selects next tab
@@ -329,8 +336,6 @@ void Dialog::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
   Event::Type e = Event::NoType;
 
   // Detect selection of previous and next tab headers and objects
-  // For some strange reason, 'tab' needs to be interpreted as keycode,
-  // not ascii??
   if(instance().eventHandler().kbdShift(mod))
   {
     if(key == KBDK_LEFT && cycleTab(-1))
@@ -353,18 +358,18 @@ void Dialog::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
   if(!handleNavEvent(e) && _focusedWidget)
   {
     if(_focusedWidget->wantsRaw() || e == Event::NoType)
-      _focusedWidget->handleKeyDown(key, mod, ascii);
+      _focusedWidget->handleKeyDown(key, mod);
     else
       _focusedWidget->handleEvent(e);
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::handleKeyUp(StellaKey key, StellaMod mod, char ascii)
+void Dialog::handleKeyUp(StellaKey key, StellaMod mod)
 {
   // Focused widget receives keyup events
   if(_focusedWidget)
-    _focusedWidget->handleKeyUp(key, mod, ascii);
+    _focusedWidget->handleKeyUp(key, mod);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -658,7 +663,7 @@ void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
                       font.getStringWidth(okText))) + 15;
   int buttonHeight = font.getLineHeight() + 4;
   ButtonWidget* b;
-#ifndef MAC_OSX
+#ifndef BSPF_MAC_OSX
   b = new ButtonWidget(this, font, _w - 2 * (buttonWidth + 7), _h - buttonHeight - 10,
                        buttonWidth, buttonHeight,
                        okText == "" ? "OK" : okText, kOKCmd);
