@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: GameInfoDialog.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: GameInfoDialog.cxx 2895 2014-06-02 20:41:19Z stephena $
 //============================================================================
 
 #include "Console.hxx"
@@ -41,7 +41,7 @@ GameInfoDialog::GameInfoDialog(
     myPropertiesLoaded(false),
     myDefaultsSelected(false)
 {
-  const GUI::Font& ifont = instance().infoFont();
+  const GUI::Font& ifont = instance().frameBuffer().infoFont();
   const int lineHeight   = font.getLineHeight(),
             fontWidth    = font.getMaxCharWidth(),
             fontHeight   = font.getFontHeight(),
@@ -152,6 +152,7 @@ GameInfoDialog::GameInfoDialog(
   items.push_back("BFSC (CPUWIZ 256K + ram)",    "BFSC"  );
   items.push_back("CV (Commavid extra ram)",     "CV"    );
   items.push_back("CM (SpectraVideo CompuMate)", "CM"    );
+  items.push_back("DASH (Boulder Dash 2)",       "DASH"  );
   items.push_back("DF (CPUWIZ 128K)",            "DF"    );
   items.push_back("DFSC (CPUWIZ 128K + ram)",    "DFSC"  );
   items.push_back("DPC (Pitfall II)",            "DPC"   );
