@@ -8,16 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2013 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2014 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: LauncherDialog.cxx 2751 2013-06-19 20:28:41Z stephena $
-//
-//   Based on code from ScummVM - Scumm Interpreter
-//   Copyright (C) 2002-2004 The ScummVM project
+// $Id: LauncherDialog.cxx 2913 2014-06-10 16:43:35Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -51,7 +48,7 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 LauncherDialog::LauncherDialog(OSystem* osystem, DialogContainer* parent,
                                int x, int y, int w, int h)
-  : Dialog(osystem, parent, x, y, w, h, true),  // use base surface
+  : Dialog(osystem, parent, x, y, w, h),
     myStartButton(NULL),
     myPrevDirButton(NULL),
     myOptionsButton(NULL),
@@ -66,7 +63,7 @@ LauncherDialog::LauncherDialog(OSystem* osystem, DialogContainer* parent,
     myRomDir(NULL),
     mySelectedItem(0)
 {
-  const GUI::Font& font = instance().launcherFont();
+  const GUI::Font& font = instance().frameBuffer().launcherFont();
 
   const int fontWidth = font.getMaxCharWidth(),
             fontHeight = font.getFontHeight(),
@@ -118,9 +115,10 @@ LauncherDialog::LauncherDialog(OSystem* osystem, DialogContainer* parent,
   if(romWidth > 0)
   {
     xpos += myList->getWidth() + 5;
-    myRomInfoWidget =
-      new RomInfoWidget(this, romWidth < 660 ? instance().smallFont() : instance().consoleFont(),
-                        xpos, ypos, romWidth, myList->getHeight());
+    myRomInfoWidget = new RomInfoWidget(this,
+        romWidth < 660 ? instance().frameBuffer().smallFont() :
+                         instance().frameBuffer().infoFont(),
+        xpos, ypos, romWidth, myList->getHeight());
   }
 
   // Add note textwidget to show any notes for the currently selected ROM
@@ -136,9 +134,9 @@ LauncherDialog::LauncherDialog(OSystem* osystem, DialogContainer* parent,
 
   // Add four buttons at the bottom
   xpos = 10;  ypos += myDir->getHeight() + 4;
-#ifndef MAC_OSX
+#ifndef BSPF_MAC_OSX
   myStartButton = new ButtonWidget(this, font, xpos, ypos, bwidth, bheight,
-                                  "Select", kStartCmd);
+                                  "Select", kLoadROMCmd);
   wid.push_back(myStartButton);
     xpos += bwidth + 8;
   myPrevDirButton = new ButtonWidget(this, font, xpos, ypos, bwidth, bheight,
@@ -167,7 +165,7 @@ LauncherDialog::LauncherDialog(OSystem* osystem, DialogContainer* parent,
   wid.push_back(myPrevDirButton);
     xpos += bwidth + 8;
   myStartButton = new ButtonWidget(this, font, xpos, ypos, bwidth, bheight,
-                                   "Select", kStartCmd);
+                                   "Select", kLoadROMCmd);
   wid.push_back(myStartButton);
     xpos += bwidth + 8;
 #endif
@@ -184,17 +182,17 @@ LauncherDialog::LauncherDialog(OSystem* osystem, DialogContainer* parent,
 
   // Create context menu for ROM list options
   VariantList l;
-  l.push_back("Override properties", "override");
+  l.push_back("Power-on options", "override");
   l.push_back("Filter listing", "filter");
   l.push_back("Reload listing", "reload");
-  myMenu = new ContextMenu(this, osystem->font(), l);
+  myMenu = new ContextMenu(this, osystem->frameBuffer().font(), l);
 
   // Create global props dialog, which is used to temporarily overrride
   // ROM properties
-  myGlobalProps = new GlobalPropsDialog(this, osystem->font());
+  myGlobalProps = new GlobalPropsDialog(this, osystem->frameBuffer().font());
 
   // Create dialog whereby the files shown in the ROM listing can be customized
-  myFilters = new LauncherFilterDialog(this, osystem->font());
+  myFilters = new LauncherFilterDialog(this, osystem->frameBuffer().font());
 
   // Figure out which filters are needed for the ROM listing
   setListFilters();
@@ -250,8 +248,8 @@ void LauncherDialog::loadConfig()
       msg.push_back("");
       msg.push_back("Click 'OK' to select a default ROM directory,");
       msg.push_back("or 'Cancel' to browse the filesystem manually.");
-      myFirstRunMsg = new GUI::MessageBox(this, instance().font(), msg,
-                                          _w, _h, kFirstRunMsgChosenCmd);
+      myFirstRunMsg = new GUI::MessageBox(this, instance().frameBuffer().font(),
+                                          msg, _w, _h, kFirstRunMsgChosenCmd);
     }
     myFirstRunMsg->show();
   }
@@ -455,14 +453,14 @@ bool LauncherDialog::matchPattern(const string& s, const string& pattern) const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void LauncherDialog::handleKeyDown(StellaKey key, StellaMod mod, char ascii)
+void LauncherDialog::handleKeyDown(StellaKey key, StellaMod mod)
 {
   // Grab the key before passing it to the actual dialog and check for
   // Control-R (reload ROM listing)
-  if(instance().eventHandler().kbdControl(mod) && key == KBDK_r)
+  if(instance().eventHandler().kbdControl(mod) && key == KBDK_R)
     updateListing();
   else
-    Dialog::handleKeyDown(key, mod, ascii);
+    Dialog::handleKeyDown(key, mod);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -484,7 +482,7 @@ void LauncherDialog::handleCommand(CommandSender* sender, int cmd,
 {
   switch (cmd)
   {
-    case kStartCmd:
+    case kLoadROMCmd:
     case ListWidget::kActivatedCmd:
     case ListWidget::kDoubleClickedCmd:
     {
@@ -545,7 +543,7 @@ void LauncherDialog::handleCommand(CommandSender* sender, int cmd,
     case kFirstRunMsgChosenCmd:
       // Show a file browser, starting from the users' home directory
       if(!myRomDir)
-        myRomDir = new BrowserDialog(this, instance().font(), _w, _h);
+        myRomDir = new BrowserDialog(this, instance().frameBuffer().font(), _w, _h);
 
       myRomDir->show("Select ROM directory:", "~",
                      BrowserDialog::Directories, kStartupRomDirChosenCmd);
