@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: RomInfoWidget.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: RomInfoWidget.cxx 2919 2014-06-13 13:35:41Z stephena $
 //============================================================================
 
 #include "FrameBuffer.hxx"
@@ -93,18 +93,13 @@ void RomInfoWidget::parseProperties()
   if(mySurface == NULL)
   {
     mySurfaceID = instance().frameBuffer().allocateSurface(
-                    320*myZoomLevel, 256*myZoomLevel, false);
+                    320*myZoomLevel, 256*myZoomLevel);
     mySurface   = instance().frameBuffer().surface(mySurfaceID);
   }
-  else
-  {
-    mySurface->setWidth(320*myZoomLevel);
-    mySurface->setHeight(256*myZoomLevel);
-  }
 
   // Initialize to empty properties entry
   mySurfaceErrorMsg = "";
-  mySurfaceIsValid = false;
+  mySurfaceIsValid = true;
   myRomInfo.clear();
 
   // Get a valid filename representing a snapshot file for this rom
@@ -114,8 +109,7 @@ void RomInfoWidget::parseProperties()
   // Read the PNG file
   try
   {
-    mySurfaceIsValid =
-      instance().png().loadImage(filename, instance().frameBuffer(), *mySurface);
+    instance().png().loadImage(filename, *mySurface);
   }
   catch(const char* msg)
   {
@@ -148,13 +142,15 @@ void RomInfoWidget::drawWidget(bool hilite)
 
   if(mySurfaceIsValid)
   {
-    uInt32 x = _x + ((_w - mySurface->getWidth()) >> 1);
-    uInt32 y = _y + ((yoff - mySurface->getHeight()) >> 1);
-    s.drawSurface(mySurface, x, y);
+    const GUI::Rect& src = mySurface->srcRect();
+    uInt32 x = _x + ((_w - src.width()) >> 1);
+    uInt32 y = _y + ((yoff - src.height()) >> 1);
+    mySurface->setDstPos(x, y);
+    s.drawSurface(mySurface);
   }
   else if(mySurfaceErrorMsg != "")
   {
-    const GUI::Font& font = instance().font();
+    const GUI::Font& font = instance().frameBuffer().font();
     uInt32 x = _x + ((_w - font.getStringWidth(mySurfaceErrorMsg)) >> 1);
     uInt32 y = _y + ((yoff - font.getLineHeight()) >> 1);
     s.drawString(font, mySurfaceErrorMsg, x, y, _w - 10, _textcolor);
