@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: UIDialog.cxx 2838 2014-01-17 23:34:03Z stephena $
+// $Id: UIDialog.cxx 2941 2014-06-30 13:45:25Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -22,7 +22,6 @@
 #include "bspf.hxx"
 
 #include "Dialog.hxx"
-#include "DebuggerDialog.hxx"
 #include "OSystem.hxx"
 #include "ListWidget.hxx"
 #include "PopUpWidget.hxx"
@@ -31,6 +30,9 @@
 #include "StringList.hxx"
 #include "TabWidget.hxx"
 #include "Widget.hxx"
+#ifdef DEBUGGER_SUPPORT
+  #include "DebuggerDialog.hxx"
+#endif
 
 #include "UIDialog.hxx"
 
@@ -39,7 +41,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
                    const GUI::Font& font)
   : Dialog(osystem, parent, 0, 0, 0, 0)
 {
-  const GUI::Font& ifont = instance().infoFont();
+  const GUI::Font& ifont = instance().frameBuffer().infoFont();
   const int lineHeight   = font.getLineHeight(),
             fontWidth    = font.getMaxCharWidth(),
             fontHeight   = font.getFontHeight(),
@@ -51,6 +53,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
   WidgetArray wid;
   VariantList items;
   ButtonWidget* b;
+  const GUI::Size& ds = instance().frameBuffer().desktopSize();
 
   // Set real dimensions
   _w = 37 * fontWidth + 10;
@@ -71,16 +74,8 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
   myLauncherWidthSlider = new SliderWidget(myTab, font, xpos, ypos, pwidth,
                                            lineHeight, "Launcher Width: ",
                                            lwidth, kLWidthChanged);
-  if(instance().desktopWidth() < 640)
-  {
-    myLauncherWidthSlider->setMinValue(320);
-    myLauncherWidthSlider->setMaxValue(instance().desktopWidth());
-  }
-  else
-  {
-    myLauncherWidthSlider->setMinValue(640);
-    myLauncherWidthSlider->setMaxValue(1920);
-  }
+  myLauncherWidthSlider->setMinValue(FrameBuffer::kFBMinW);
+  myLauncherWidthSlider->setMaxValue(ds.w);
   myLauncherWidthSlider->setStepValue(10);
   wid.push_back(myLauncherWidthSlider);
   myLauncherWidthLabel =
@@ -93,16 +88,8 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
   myLauncherHeightSlider = new SliderWidget(myTab, font, xpos, ypos, pwidth,
                                             lineHeight, "Launcher Height: ",
                                             lwidth, kLHeightChanged);
-  if(instance().desktopHeight() < 480)
-  {
-    myLauncherHeightSlider->setMinValue(240);
-    myLauncherHeightSlider->setMaxValue(instance().desktopHeight());
-  }
-  else
-  {
-    myLauncherHeightSlider->setMinValue(480);
-    myLauncherHeightSlider->setMaxValue(1200);
-  }
+  myLauncherHeightSlider->setMinValue(FrameBuffer::kFBMinH);
+  myLauncherHeightSlider->setMaxValue(ds.h);
   myLauncherHeightSlider->setStepValue(10);
   wid.push_back(myLauncherHeightSlider);
   myLauncherHeightLabel =
@@ -160,6 +147,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
   // 2) Debugger options
   wid.clear();
   tabID = myTab->addTab(" Debugger ");
+#ifdef DEBUGGER_SUPPORT
   lwidth = font.getStringWidth("Debugger Height: ");
   xpos = ypos = vBorder;
 
@@ -168,7 +156,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
                                            lineHeight, "Debugger Width: ",
                                            lwidth, kDWidthChanged);
   myDebuggerWidthSlider->setMinValue(DebuggerDialog::kSmallFontMinW);
-  myDebuggerWidthSlider->setMaxValue(osystem->desktopWidth());
+  myDebuggerWidthSlider->setMaxValue(ds.w);
   myDebuggerWidthSlider->setStepValue(10);
   wid.push_back(myDebuggerWidthSlider);
   myDebuggerWidthLabel =
@@ -182,7 +170,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
                                             lineHeight, "Debugger Height: ",
                                             lwidth, kDHeightChanged);
   myDebuggerHeightSlider->setMinValue(DebuggerDialog::kSmallFontMinH);
-  myDebuggerHeightSlider->setMaxValue(osystem->desktopHeight());
+  myDebuggerHeightSlider->setMaxValue(ds.h);
   myDebuggerHeightSlider->setStepValue(10);
   wid.push_back(myDebuggerHeightSlider);
   myDebuggerHeightLabel =
@@ -225,7 +213,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
   // (and when it's actually been compiled into the app)
   bool debuggerAvailable = 
 #if defined(DEBUGGER_SUPPORT) && defined(WINDOWED_SUPPORT)
-    (instance().desktopWidth() >= 800 && instance().desktopHeight() >= 600);
+    (ds.w >= 800 && ds.h >= 600);  // TODO - maybe this logic can disappear?
 #else
   false;
 #endif
@@ -239,6 +227,10 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
 
   // Add items for tab 1
   addToFocusList(wid, myTab, tabID);
+#else
+  new StaticTextWidget(myTab, font, 0, 20, _w-20, fontHeight,
+                       "Debugger support not included", kTextAlignCenter);
+#endif
 
   //////////////////////////////////////////////////////////
   // 3) Misc. options
@@ -247,16 +239,7 @@ UIDialog::UIDialog(OSystem* osystem, DialogContainer* parent,
   lwidth = font.getStringWidth("Mouse wheel scroll: ");
   pwidth = font.getStringWidth("Standard");
   xpos = ypos = vBorder;
-
-  // UI Palette
   ypos += 1;
-  items.clear();
-  items.push_back("Standard", "1");
-  items.push_back("Classic", "2");
-  myPalettePopup = new PopUpWidget(myTab, font, xpos, ypos, pwidth, lineHeight,
-                                   items, "Interface Palette: ", lwidth);
-  wid.push_back(myPalettePopup);
-  ypos += lineHeight + 4;
 
   // Delay between quick-selecting characters in ListWidget
   items.clear();
@@ -315,12 +298,12 @@ void UIDialog::loadConfig()
 {
   // Launcher size
   const GUI::Size& ls = instance().settings().getSize("launcherres");
-  int w = ls.w, h = ls.h;
+  uInt32 w = ls.w, h = ls.h;
 
-  w = BSPF_max(w, 320);
-  h = BSPF_max(h, 240);
-  w = BSPF_min(w, 1920);
-  h = BSPF_min(h, 1200);
+  w = BSPF_max(w, (uInt32)FrameBuffer::kFBMinW);
+  h = BSPF_max(h, (uInt32)FrameBuffer::kFBMinH);
+  w = BSPF_min(w, instance().frameBuffer().desktopSize().w);
+  h = BSPF_min(h, instance().frameBuffer().desktopSize().h);
 
   myLauncherWidthSlider->setValue(w);
   myLauncherWidthLabel->setValue(w);
@@ -343,10 +326,10 @@ void UIDialog::loadConfig()
   // Debugger size
   const GUI::Size& ds = instance().settings().getSize("dbg.res");
   w = ds.w, h = ds.h;
-  w = BSPF_max(w, (int)DebuggerDialog::kSmallFontMinW);
-  h = BSPF_max(h, (int)DebuggerDialog::kSmallFontMinH);
-  w = BSPF_min(w, (int)instance().desktopWidth());
-  h = BSPF_min(h, (int)instance().desktopHeight());
+  w = BSPF_max(w, (uInt32)DebuggerDialog::kSmallFontMinW);
+  h = BSPF_max(h, (uInt32)DebuggerDialog::kSmallFontMinH);
+  w = BSPF_min(w, ds.w);
+  h = BSPF_min(h, ds.h);
 
   myDebuggerWidthSlider->setValue(w);
   myDebuggerWidthLabel->setValue(w);
@@ -358,10 +341,6 @@ void UIDialog::loadConfig()
   myDebuggerFontStyle->setSelected(style, "0");
 #endif
 
-  // UI palette
-  const string& pal = instance().settings().getString("uipalette");
-  myPalettePopup->setSelected(pal, "1");
-
   // Listwidget quick delay
   const string& delay = instance().settings().getString("listdelay");
   myListDelayPopup->setSelected(delay, "300");
@@ -402,10 +381,6 @@ void UIDialog::saveConfig()
   instance().settings().setValue("dbg.fontstyle",
     myDebuggerFontStyle->getSelectedTag().toString());
 
-  // UI palette
-  instance().settings().setValue("uipalette",
-    myPalettePopup->getSelectedTag().toString());
-
   // Listwidget quick delay
   instance().settings().setValue("listdelay",
     myListDelayPopup->getSelectedTag().toString());
@@ -424,32 +399,33 @@ void UIDialog::setDefaults()
   {
     case 0:  // Launcher options
     {
-      int w = BSPF_min(instance().desktopWidth(), 640u);
-      int h = BSPF_min(instance().desktopHeight(), 480u);
+      uInt32 w = BSPF_min(instance().frameBuffer().desktopSize().w, 1000u);
+      uInt32 h = BSPF_min(instance().frameBuffer().desktopSize().h, 600u);
       myLauncherWidthSlider->setValue(w);
       myLauncherWidthLabel->setValue(w);
       myLauncherHeightSlider->setValue(h);
       myLauncherHeightLabel->setValue(h);
       myLauncherFontPopup->setSelected("medium", "");
-      myRomViewerPopup->setSelected("0", "");
+      myRomViewerPopup->setSelected("1", "");
       myLauncherExitPopup->setSelected("0", "");
       break;
     }
 
     case 1:  // Debugger options
     {
-      int w = BSPF_min(instance().desktopWidth(), (uInt32)DebuggerDialog::kMediumFontMinW);
-      int h = BSPF_min(instance().desktopHeight(), (uInt32)DebuggerDialog::kMediumFontMinH);
+#ifdef DEBUGGER_SUPPORT
+      uInt32 w = BSPF_min(instance().frameBuffer().desktopSize().w, (uInt32)DebuggerDialog::kMediumFontMinW);
+      uInt32 h = BSPF_min(instance().frameBuffer().desktopSize().h, (uInt32)DebuggerDialog::kMediumFontMinH);
       myDebuggerWidthSlider->setValue(w);
       myDebuggerWidthLabel->setValue(w);
       myDebuggerHeightSlider->setValue(h);
       myDebuggerHeightLabel->setValue(h);
       myDebuggerFontStyle->setSelected("0");
+#endif
       break;
     }
 
     case 2:  // Misc. options
-      myPalettePopup->setSelected("1");
       myListDelayPopup->setSelected("300");
       myWheelLinesPopup->setSelected("4");
       break;
@@ -474,6 +450,7 @@ void UIDialog::handleCommand(CommandSender* sender, int cmd, int data, int id)
       myLauncherHeightLabel->setValue(myLauncherHeightSlider->getValue());
       break;
 
+#ifdef DEBUGGER_SUPPORT
     case kDWidthChanged:
       myDebuggerWidthLabel->setValue(myDebuggerWidthSlider->getValue());
       break;
@@ -502,11 +479,11 @@ void UIDialog::handleCommand(CommandSender* sender, int cmd, int data, int id)
       myDebuggerHeightSlider->setValue(DebuggerDialog::kLargeFontMinH);
       myDebuggerHeightLabel->setValue(DebuggerDialog::kLargeFontMinH);
       break;
+#endif
 
     case kOKCmd:
       saveConfig();
       close();
-      instance().setUIPalette();
       break;
 
     case kDefaultsCmd:
